# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('webflow')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def api_token(self) -> Optional[str]:
        """
        Webflow API v2 bearer token for authentication. Can also be set via WEBFLOW_API_TOKEN environment variable.
        """
        return __config__.get('apiToken')

