# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .asset import *
from .asset_folder import *
from .collection import *
from .collection_field import *
from .collection_item import *
from .ecommerce_settings import *
from .get_authorized_user import *
from .get_token_info import *
from .inline_script import *
from .page_content import *
from .page_custom_code import *
from .page_data import *
from .provider import *
from .redirect import *
from .registered_script import *
from .robots_txt import *
from .site import *
from .site_custom_code import *
from .user import *
from .webhook import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_webflow.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_webflow.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "webflow",
  "mod": "index",
  "fqn": "pulumi_webflow",
  "classes": {
   "webflow:index:Asset": "Asset",
   "webflow:index:AssetFolder": "AssetFolder",
   "webflow:index:Collection": "Collection",
   "webflow:index:CollectionField": "CollectionField",
   "webflow:index:CollectionItem": "CollectionItem",
   "webflow:index:EcommerceSettings": "EcommerceSettings",
   "webflow:index:InlineScript": "InlineScript",
   "webflow:index:PageContent": "PageContent",
   "webflow:index:PageCustomCode": "PageCustomCode",
   "webflow:index:PageData": "PageData",
   "webflow:index:Redirect": "Redirect",
   "webflow:index:RegisteredScript": "RegisteredScript",
   "webflow:index:RobotsTxt": "RobotsTxt",
   "webflow:index:Site": "Site",
   "webflow:index:SiteCustomCode": "SiteCustomCode",
   "webflow:index:User": "User",
   "webflow:index:Webhook": "Webhook"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "webflow",
  "token": "pulumi:providers:webflow",
  "fqn": "pulumi_webflow",
  "class": "Provider"
 }
]
"""
)
