# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import errno
from setuptools import setup, find_packages
from setuptools.command.install import install
from subprocess import check_call


VERSION = "0.9.2"
def readme():
    try:
        with open('README.md', encoding='utf-8') as f:
            return f.read()
    except FileNotFoundError:
        return "webflow Pulumi Package - Development Version"


setup(name='pulumi_webflow',
      python_requires='>=3.9',
      version=VERSION,
      description="Unofficial community-maintained Pulumi provider for managing Webflow sites, redirects, and robots.txt. Not affiliated with Pulumi Corporation or Webflow, Inc.",
      long_description=readme(),
      long_description_content_type='text/markdown',
      url='https://github.com/JDetmar/pulumi-webflow',
      project_urls={
          'Repository': 'https://github.com/JDetmar/pulumi-webflow'
      },
      packages=find_packages(),
      package_data={
          'pulumi_webflow': [
              'py.typed',
              'pulumi-plugin.json',
          ]
      },
      install_requires=[
          'parver>=0.2.1',
          'pulumi>=3.165.0,<4.0.0',
          'semver>=2.8.1',
          'typing-extensions>=4.11,<5; python_version < "3.11"'
      ],
      zip_safe=False)
